@@ -1,4 +1,5 @@
-package DBICTest::Schema::LinerNotes;
+package # hide from PAUSE 
+    DBICTest::Schema::LinerNotes;
 
 use base qw/DBIx::Class::Core/;
 
@@ -9,8 +10,12 @@ DBICTest::Schema::LinerNotes->add_columns(
   },
   'notes' => {
     data_type => 'varchar',
+    size      => 100,
   },
 );
 DBICTest::Schema::LinerNotes->set_primary_key('liner_id');
+DBICTest::Schema::LinerNotes->belongs_to(
+  'cd', 'DBICTest::Schema::CD', 'liner_id'
+);
 
 1;
